nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Seed

Struct Seed 

#[repr(transparent)]
pub struct Seed(pub u32);
CRC seed register

Tuple Fields

0: u32

Implementations

Source

impl Seed

pub const fn crc_seed(&self) -> u32

A write access to this register will load CRC seed value to CRC_SUM register with selected bit order and 1’s complement pre-processes. A write access to this register will overrule the CRC calculation in progresses.

pub const fn set_crc_seed(&mut self, val: u32)

A write access to this register will load CRC seed value to CRC_SUM register with selected bit order and 1’s complement pre-processes. A write access to this register will overrule the CRC calculation in progresses.